#!/bin/sh

DIRECTORY=$1

if grep -qs 7020 /proc/bus/dreambox ; then
	BOXTYPE=dm7020
	SND=secondstage-dm7020-35.bin
	OPTIONS="--eraseblock=0x4000 -n -b"
elif grep -qs 600PVR /proc/bus/dreambox ; then
	BOXTYPE=dm600pvr
	SND=secondstage-dm600pvr-51.bin
	OPTIONS="--eraseblock=0x4000 -n -b"
else 
	BOXTYPE=dm7025
	SND=secondstage-dm7025-51.bin
	OPTIONS="--eraseblock=0x4000 -n -l"
fi

echo $BOXTYPE " found"
echo "***"

DATE=`date +%Y%m%d`
MKFS=/usr/bin/mkfs.jffs2
BUILDIMAGE=/usr/bin/buildimage
BACKUPIMAGE=$DIRECTORY/backup_image_$BOXTYPE$DATE.nfi

if [ ! -f $MKFS ] ; then
	echo $MKFS " not found"
	exit 0
fi
if [ ! -f $BUILDIMAGE ] ; then
	echo $BUILDIMAGE " not found"
	exit 0
fi

rm -rf $DIRECTORY/bi
mkdir -p $DIRECTORY/bi
mkdir -p /tmp/bi/root
mkdir -p /tmp/bi/boot

mount -t jffs2 /dev/mtdblock/3 /tmp/bi/root
mount -t jffs2 /dev/mtdblock/2 /tmp/bi/boot

echo "download " $SND
wget -q http://sources.dreamboxupdate.com/download/7020/$SND -O /tmp/secondstage.bin > /dev/null

	
	
if [ -f /tmp/secondstage.bin ] ; then
	echo "create boot.jffs2"
	$MKFS --root=/tmp/bi/boot --faketime --output=$DIRECTORY/bi/boot.jffs2 $OPTIONS
	echo "create root.jffs2"
	$MKFS --root=/tmp/bi/root --faketime --output=$DIRECTORY/bi/root.jffs2 $OPTIONS
	echo "create secondstage"
	gzip -c /tmp/secondstage.bin > $DIRECTORY/bi/main.bin.gz
	rm /tmp/secondstage.bin
	
	if [ $BOXTYPE = "dm7025" ] ; then
		echo "create 7025 nfi-image"
		$BUILDIMAGE $DIRECTORY/bi/main.bin.gz $DIRECTORY/bi/boot.jffs2 $DIRECTORY/bi/root.jffs2 $BOXTYPE > $BACKUPIMAGE
	elif [ $BOXTYPE = "dm7020" ] ; then
		echo "create 7020 nfi-image"
		$BUILDIMAGE $DIRECTORY/bi/main.bin.gz $DIRECTORY/bi/boot.jffs2 $DIRECTORY/bi/root.jffs2 > $BACKUPIMAGE
	elif [ $BOXTYPE = "dm600pvr" ] ; then
		echo "create 600pvr nfi-image"
		$BUILDIMAGE $DIRECTORY/bi/main.bin.gz $DIRECTORY/bi/boot.jffs2 $DIRECTORY/bi/root.jffs2 $BOXTYPE > $BACKUPIMAGE
	fi

	if [ -f $BACKUPIMAGE ] ; then
		echo "nfi-image create on " $BACKUPIMAGE
		echo "***"
	fi
fi

umount /tmp/bi/root
umount /tmp/bi/boot
rm -rf /tmp/bi
rm -rf $DIRECTORY/bi

exit